"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var ts_guard_decorator_1 = require("ts-guard-decorator");
var svg_cache_service_1 = require("./svg-cache.service");
var InlineSVGDirective = (function () {
    function InlineSVGDirective(_el, _svgCache) {
        this._el = _el;
        this._svgCache = _svgCache;
        this.replaceContents = true;
        this.prepend = false;
        this.cacheSVG = true;
        this.forceEvalStyles = false;
        this.evalScripts = 'always';
        this.onSVGInserted = new core_1.EventEmitter();
        this.onSVGFailed = new core_1.EventEmitter();
        this._supportsSVG = true;
        this._ranScripts = {};
    }
    InlineSVGDirective.prototype.ngOnInit = function () {
        this._insertSVG();
    };
    InlineSVGDirective.prototype.ngOnChanges = function (changes) {
        if (changes['inlineSVG']) {
            this._insertSVG();
        }
    };
    InlineSVGDirective.prototype._insertSVG = function () {
        var _this = this;
        if (!this._supportsSVG) {
            return;
        }
        if (!this._checkSVGSupport()) {
            this._fail('Embed SVG not supported by browser');
            this._supportsSVG = false;
            return;
        }
        if (!this.inlineSVG) {
            this._fail('No URL passed to [inlineSVG]');
            return;
        }
        if (this.inlineSVG.charAt(0) === '#' || this.inlineSVG.indexOf('.svg#') > -1) {
            var elSvg = document.createElementNS('http://www.w3.org/2000/svg', 'svg');
            var elSvgUse = document.createElementNS('http://www.w3.org/2000/svg', 'use');
            elSvgUse.setAttributeNS('http://www.w3.org/1999/xlink', 'href', this.inlineSVG);
            elSvg.appendChild(elSvgUse);
            this._insertEl(elSvg);
            this.onSVGInserted.emit(elSvg);
            return;
        }
        if (this.inlineSVG !== this._prevUrl) {
            this._prevUrl = this.inlineSVG;
            this._svgCache.getSVG(this.inlineSVG, this.cacheSVG)
                .subscribe(function (svg) {
                if (svg && _this._el.nativeElement) {
                    if (_this.removeSVGAttributes) {
                        _this._removeAttributes(svg, _this.removeSVGAttributes);
                    }
                    _this._insertEl(svg);
                    _this._evalScripts(svg, _this.inlineSVG);
                    if (_this.forceEvalStyles) {
                        var styleTags = svg.querySelectorAll('style');
                        Array.prototype.forEach.call(styleTags, function (tag) { return tag.textContent += ''; });
                    }
                    _this.onSVGInserted.emit(svg);
                }
            }, function (err) {
                _this._fail(err);
            });
        }
    };
    InlineSVGDirective.prototype._removeAttributes = function (svg, attrs) {
        var innerEls = svg.getElementsByTagName('*');
        for (var i = 0; i < innerEls.length; i++) {
            var elAttrs = innerEls[i].attributes;
            for (var j = 0; j < elAttrs.length; j++) {
                if (attrs.indexOf(elAttrs[j].name.toLowerCase()) > -1) {
                    innerEls[i].removeAttribute(elAttrs[j].name);
                }
            }
        }
    };
    InlineSVGDirective.prototype._insertEl = function (el) {
        if (this.replaceContents && !this.prepend) {
            this._el.nativeElement.innerHTML = '';
        }
        if (this.prepend) {
            this._el.nativeElement.insertBefore(el, this._el.nativeElement.firstChild);
        }
        else {
            this._el.nativeElement.appendChild(el);
        }
    };
    InlineSVGDirective.prototype._evalScripts = function (svg, url) {
        var scripts = svg.querySelectorAll('script');
        var scriptsToEval = [];
        var script, scriptType;
        for (var i = 0; i < scripts.length; i++) {
            scriptType = scripts[i].getAttribute('type');
            if (!scriptType || scriptType === 'application/ecmascript' || scriptType === 'application/javascript') {
                script = scripts[i].innerText || scripts[i].textContent;
                scriptsToEval.push(script);
                svg.removeChild(scripts[i]);
            }
        }
        if (scriptsToEval.length > 0 && (this.evalScripts === 'always' ||
            (this.evalScripts === 'once' && !this._ranScripts[url]))) {
            for (var i = 0; i < scriptsToEval.length; i++) {
                new Function(scriptsToEval[i])(window);
            }
            this._ranScripts[url] = true;
        }
    };
    InlineSVGDirective.prototype._checkSVGSupport = function () {
        return typeof SVGRect !== 'undefined';
    };
    InlineSVGDirective.prototype._fail = function (msg) {
        this.onSVGFailed.emit(msg);
        if (this.fallbackImgUrl) {
            var elImg = document.createElement('IMG');
            elImg.src = this.fallbackImgUrl;
            this._insertEl(elImg);
        }
    };
    return InlineSVGDirective;
}());
InlineSVGDirective.decorators = [
    { type: core_1.Directive, args: [{
                selector: '[inlineSVG]',
                providers: [svg_cache_service_1.SVGCacheService]
            },] },
];
InlineSVGDirective.ctorParameters = function () { return [
    { type: core_1.ElementRef, },
    { type: svg_cache_service_1.SVGCacheService, },
]; };
InlineSVGDirective.propDecorators = {
    'inlineSVG': [{ type: core_1.Input },],
    'replaceContents': [{ type: core_1.Input },],
    'prepend': [{ type: core_1.Input },],
    'cacheSVG': [{ type: core_1.Input },],
    'removeSVGAttributes': [{ type: core_1.Input },],
    'forceEvalStyles': [{ type: core_1.Input },],
    'evalScripts': [{ type: core_1.Input },],
    'fallbackImgUrl': [{ type: core_1.Input },],
    'onSVGInserted': [{ type: core_1.Output },],
    'onSVGFailed': [{ type: core_1.Output },],
};
__decorate([
    ts_guard_decorator_1.default(typeof window !== 'undefined'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], InlineSVGDirective.prototype, "ngOnInit", null);
__decorate([
    ts_guard_decorator_1.default(typeof window !== 'undefined'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], InlineSVGDirective.prototype, "ngOnChanges", null);
exports.InlineSVGDirective = InlineSVGDirective;
